/**
 * See https://fdc3.finos.org/docs/fdc3-intro, and https://github.com/finos/FDC3/tree/master/src/api
 */
import { AppIntent, Channel, Context, ContextHandler, Intents, IntentResolution } from '@finos/fdc3';
/**
 * @public
 */
export type FDC3Intents = Intents;
/**
 * @public
 */
export type FDC3ContextHandler = ContextHandler;
/**
 * @public
 */
export interface FDC3AppIntent extends AppIntent {
}
/**
 * @public
 */
export interface FDC3Context extends Context {
}
/**
 * @public
 */
export interface FDC3IntentResolution extends IntentResolution {
}
/**
 * @public
 */
export interface FDC3Channel extends Channel {
}
/**
 * The FDC3 API interface.
 * @public
 */
interface FDC3 {
    /**
     * Whether the FDC3 API is ready.
     * @public
     */
    isReady: boolean;
    /**
     * Adds intent listeners for the specified intents.
     * @public
     * @param listeners - The intent listeners to add.
     */
    addIntentListeners(listeners: Map<FDC3Intents, FDC3ContextHandler>): void;
    /**
     * Finds an app that supports the specified intent.
     * @public
     * @param intent - The intent to find an app for.
     * @param context - The context to use.
     * @returns A promise that resolves with the app and its metadata.
     */
    findIntent(intent: FDC3Intents, context?: FDC3Context): Promise<FDC3AppIntent>;
    /**
     * Finds all the intents supported by the specified context.
     * @public
     * @param context - The context to use.
     * @returns A promise that resolves with an array of all matching intents and their metadata.
     */
    findIntentsByContext(context: FDC3Context): Promise<FDC3AppIntent[]>;
    /**
     * Raises the specified intent with the specified context.
     * @public
     * @param context - The context to use.
     * @param intent - The intent to raise.
     * @returns A promise that resolves with the result of the intent resolution.
     */
    raiseIntent(context: FDC3Context, intent?: FDC3Intents): Promise<FDC3IntentResolution>;
    /**
     * Joins the specified channel.
     * @public
     * @param channelId - The ID of the channel to join.
     * @returns A promise that resolves when the join is successful.
     */
    joinChannel(channelId: string): Promise<void>;
    /**
     * Gets or creates the specified channel.
     * @public
     * @param  channelId - The ID of the channel to get or create.
     * @returns A promise that resolves with the channel object.
     */
    getOrCreateChannel(channelId: string): Promise<FDC3Channel>;
    /**
     * Broadcasts the specified context on the specified channel.
     * @public
     * @param channelId - The ID of the channel to broadcast on.
     * @param context - The context to broadcast.
     * @returns A promise that resolves when the broadcast is successful.
     */
    broadcastOnChannel(channelId: string, context: FDC3Context): Promise<void>;
}
/**
 * The DI token for the FDC3Service interface.
 * @internal
 */
export declare const FDC3: import("@microsoft/fast-foundation").InterfaceSymbol<FDC3>;
export {};
//# sourceMappingURL=fdc3.d.ts.map